@@ -6,7 +6,7 @@ This file is part of minos framework.
 Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
 """
 
-__version__ = "0.1.7"
+__version__ = "0.1.9"
 
 from .configuration import (
     BROKER,
@@ -26,9 +26,11 @@ from .configuration import (
 )
 from .constants import (
     NULL_UUID,
+    UUID_REGEX,
 )
 from .database import (
     PostgreSqlMinosDatabase,
+    PostgreSqlPool,
 )
 from .exceptions import (
     EmptyMinosModelSequenceException,
@@ -53,7 +55,6 @@ from .exceptions import (
     MinosRepositoryManuallySetAggregateIdentifierException,
     MinosRepositoryManuallySetAggregateVersionException,
     MinosRepositoryNotProvidedException,
-    MinosRepositoryUnknownActionException,
     MinosReqAttributeException,
     MinosSagaManagerException,
     MinosSagaManagerNotProvidedException,
@@ -80,6 +81,7 @@ from .meta import (
     self_or_classmethod,
 )
 from .model import (
+    Action,
     Aggregate,
     AggregateDiff,
     AggregateRef,
@@ -92,14 +94,18 @@ from .model import (
     CommandReply,
     CommandStatus,
     DataTransferObject,
-    Decimal,
     DeclarativeModel,
     DynamicModel,
-    Enum,
+    Entity,
+    EntitySet,
+    EntitySetDiff,
+    EntitySetDiffEntry,
     Event,
     Field,
-    FieldsDiff,
-    Fixed,
+    FieldDiff,
+    FieldDiffContainer,
+    GenericTypeProjector,
+    IncrementalFieldDiff,
     MinosModel,
     MissingSentinel,
     Model,
@@ -112,6 +118,9 @@ from .model import (
     TypeHintBuilder,
     TypeHintComparator,
     ValueObject,
+    ValueObjectSet,
+    ValueObjectSetDiff,
+    ValueObjectSetDiffEntry,
 )
 from .networks import (
     MinosBroker,
@@ -131,7 +140,6 @@ from .repository import (
     InMemoryRepository,
     MinosRepository,
     PostgreSqlRepository,
-    RepositoryAction,
     RepositoryEntry,
 )
 from .saga import (
