@@ -8,6 +8,9 @@ Minos framework can not be copied and/or distributed without the express permiss
 from .abc import (
     Model,
 )
+from .actions import (
+    Action,
+)
 from .declarative import (
     Aggregate,
     AggregateDiff,
@@ -16,15 +19,24 @@ from .declarative import (
     CommandReply,
     CommandStatus,
     DeclarativeModel,
+    Entity,
+    EntitySet,
+    EntitySetDiff,
+    EntitySetDiffEntry,
     Event,
     MinosModel,
     ValueObject,
+    ValueObjectSet,
+    ValueObjectSetDiff,
+    ValueObjectSetDiffEntry,
 )
 from .dynamic import (
     BucketModel,
     DataTransferObject,
     DynamicModel,
-    FieldsDiff,
+    FieldDiff,
+    FieldDiffContainer,
+    IncrementalFieldDiff,
 )
 from .fields import (
     Field,
@@ -37,9 +49,7 @@ from .serializers import (
     AvroSchemaEncoder,
 )
 from .types import (
-    Decimal,
-    Enum,
-    Fixed,
+    GenericTypeProjector,
     MissingSentinel,
     ModelRef,
     ModelRefExtractor,
