@@ -12,9 +12,6 @@ from __future__ import (
 from datetime import (
     datetime,
 )
-from enum import (
-    Enum,
-)
 from typing import (
     TYPE_CHECKING,
     Iterable,
@@ -26,38 +23,18 @@ from uuid import (
     UUID,
 )
 
-from ..exceptions import (
-    MinosRepositoryUnknownActionException,
-)
 from ..importlib import (
     import_module,
 )
 
 if TYPE_CHECKING:
     from ..model import (
+        Action,
         Aggregate,
         AggregateDiff,
     )
 
 
-class RepositoryAction(Enum):
-    """Enum class that describes the available repository actions."""
-
-    CREATE = "create"
-    UPDATE = "update"
-    DELETE = "delete"
-
-    @classmethod
-    def value_of(cls, value: str) -> Optional[RepositoryAction]:
-        """Get the action based on its text representation."""
-        for item in cls.__members__.values():
-            if item.value == value:
-                return item
-        raise MinosRepositoryUnknownActionException(
-            f"The given value does not match with any enum items. Obtained {value}"
-        )
-
-
 class RepositoryEntry:
     """Class that represents an entry (or row) on the events repository database which stores the aggregate changes."""
 
@@ -71,13 +48,17 @@ class RepositoryEntry:
         version: int,
         data: Union[bytes, memoryview] = bytes(),
         id: Optional[int] = None,
-        action: Optional[Union[str, RepositoryAction]] = None,
+        action: Optional[Union[str, Action]] = None,
         created_at: Optional[datetime] = None,
     ):
         if isinstance(data, memoryview):
             data = data.tobytes()
         if action is not None and isinstance(action, str):
-            action = RepositoryAction.value_of(action)
+            from ..model import (
+                Action,
+            )
+
+            action = Action.value_of(action)
 
         self.aggregate_uuid = aggregate_uuid
         self.aggregate_name = aggregate_name
@@ -92,7 +73,7 @@ class RepositoryEntry:
     def from_aggregate_diff(cls, aggregate_diff: AggregateDiff) -> RepositoryEntry:
         """Build a new instance from an ``Aggregate``.
 
-        :param aggregate_diff: The aggregate instance.
+        :param aggregate_diff: The aggregate difference.
         :return: A new ``RepositoryEntry`` instance.
         """
         # noinspection PyTypeChecker
@@ -117,11 +98,15 @@ class RepositoryEntry:
         """
         from ..model import (
             AggregateDiff,
-            FieldsDiff,
+            FieldDiffContainer,
         )
 
         return AggregateDiff(
-            self.aggregate_uuid, self.aggregate_name, self.version, FieldsDiff.from_avro_bytes(self.data)
+            self.aggregate_uuid,
+            self.aggregate_name,
+            self.version,
+            self.action,
+            FieldDiffContainer.from_avro_bytes(self.data),
         )
 
     def __eq__(self, other: "RepositoryEntry") -> bool:
