@@ -35,7 +35,6 @@ from ...importlib import (
 )
 from ...repository import (
     MinosRepository,
-    RepositoryAction,
     RepositoryEntry,
 )
 from ..entries import (
@@ -69,7 +68,7 @@ class PostgreSqlSnapshotBuilder(PostgreSqlSnapshotSetup):
     def _from_config(cls, *args, config: MinosConfig, **kwargs) -> PostgreSqlSnapshotBuilder:
         return cls(*args, **config.snapshot._asdict(), **kwargs)
 
-    async def are_synced(self, aggregate_name: str, aggregate_uuids: set[UUID]) -> bool:
+    async def are_synced(self, aggregate_name: str, aggregate_uuids: set[UUID], **kwargs) -> bool:
         """Check if the snapshot has the latest version of a list of aggregates.
 
         :param aggregate_name: Class name of the ``Aggregate`` to be checked.
@@ -78,30 +77,33 @@ class PostgreSqlSnapshotBuilder(PostgreSqlSnapshotSetup):
         :return: ``True`` if has the latest version for all the identifiers or ``False`` otherwise.
         """
         for aggregate_uuid in aggregate_uuids:
-            if not await self.is_synced(aggregate_name, aggregate_uuid):
+            if not await self.is_synced(aggregate_name, aggregate_uuid, **kwargs):
                 return False
         return True
 
-    async def is_synced(self, aggregate_name: str, aggregate_uuid: UUID) -> bool:
+    async def is_synced(self, aggregate_name: str, aggregate_uuid: UUID, **kwargs) -> bool:
         """Check if the snapshot has the latest version of an ``Aggregate`` instance.
 
         :param aggregate_name: Class name of the ``Aggregate`` to be checked.
         :param aggregate_uuid: Identifier of the ``Aggregate`` instance to be checked.
         :return: ``True`` if has the latest version for the identifier or ``False`` otherwise.
         """
-        query = self._repository.select(
-            id_ge=await self._load_offset(), aggregate_name=aggregate_name, aggregate_uuid=aggregate_uuid
+        offset = await self._load_offset(**kwargs)
+        iterable = self._repository.select(
+            id_ge=offset, aggregate_name=aggregate_name, aggregate_uuid=aggregate_uuid, **kwargs
         )
-        async for _ in query:
+        try:
+            await iterable.__anext__()
             return False
-        return True
+        except StopAsyncIteration:
+            return True
 
-    async def dispatch(self) -> NoReturn:
+    async def dispatch(self, **kwargs) -> NoReturn:
         """Perform a dispatching step, based on the sequence of non already processed ``RepositoryEntry`` objects.
 
         :return: This method does not return anything.
         """
-        offset = await self._load_offset()
+        offset = await self._load_offset(**kwargs)
 
         ids = set()
 
@@ -112,19 +114,19 @@ class PostgreSqlSnapshotBuilder(PostgreSqlSnapshotSetup):
                 ids.remove(o)
             return o
 
-        async for entry in self._repository.select(id_gt=offset):
+        async for entry in self._repository.select(id_gt=offset, **kwargs):
             try:
-                await self._dispatch_one(entry)
+                await self._dispatch_one(entry, **kwargs)
             except MinosPreviousVersionSnapshotException:
                 pass
             offset = _update_offset(entry, offset)
 
         await self._store_offset(offset)
 
-    async def _load_offset(self) -> int:
+    async def _load_offset(self, **kwargs) -> int:
         # noinspection PyBroadException
         try:
-            raw = await self.submit_query_and_fetchone(_SELECT_OFFSET_QUERY)
+            raw = await self.submit_query_and_fetchone(_SELECT_OFFSET_QUERY, **kwargs)
             return raw[0]
         except Exception:
             return 0
@@ -132,65 +134,67 @@ class PostgreSqlSnapshotBuilder(PostgreSqlSnapshotSetup):
     async def _store_offset(self, offset: int) -> NoReturn:
         await self.submit_query(_INSERT_OFFSET_QUERY, {"value": offset})
 
-    async def _dispatch_one(self, event_entry: RepositoryEntry) -> Optional[SnapshotEntry]:
-        if event_entry.action is RepositoryAction.DELETE:
-            return await self._submit_delete(event_entry)
+    async def _dispatch_one(self, event_entry: RepositoryEntry, **kwargs) -> Optional[SnapshotEntry]:
+        if event_entry.action.is_delete:
+            return await self._submit_delete(event_entry, **kwargs)
 
-        instance = await self._build_instance(event_entry)
-        return await self._submit_instance(instance)
+        instance = await self._build_instance(event_entry, **kwargs)
+        return await self._submit_instance(instance, **kwargs)
 
-    async def _submit_delete(self, entry: RepositoryEntry) -> NoReturn:
+    async def _submit_delete(self, entry: RepositoryEntry, **kwargs) -> NoReturn:
         params = {
             "aggregate_uuid": entry.aggregate_uuid,
             "aggregate_name": entry.aggregate_name,
             "version": entry.version,
             "data": None,
         }
-        await self.submit_query_and_fetchone(_INSERT_ONE_SNAPSHOT_ENTRY_QUERY, params)
+        await self.submit_query_and_fetchone(_INSERT_ONE_SNAPSHOT_ENTRY_QUERY, params, **kwargs)
 
-    async def _build_instance(self, event_entry: RepositoryEntry) -> Aggregate:
+    async def _build_instance(self, event_entry: RepositoryEntry, **kwargs) -> Aggregate:
         # noinspection PyTypeChecker
         diff = event_entry.aggregate_diff
-        instance = await self._update_if_exists(diff)
+        instance = await self._update_if_exists(diff, **kwargs)
         return instance
 
-    async def _update_if_exists(self, diff: AggregateDiff) -> Aggregate:
+    async def _update_if_exists(self, aggregate_diff: AggregateDiff, **kwargs) -> Aggregate:
         # noinspection PyBroadException
         try:
             # noinspection PyTypeChecker
-            previous = await self._select_one_aggregate(diff.uuid, diff.name)
+            previous = await self._select_one_aggregate(aggregate_diff.uuid, aggregate_diff.name, **kwargs)
         except Exception:
             # noinspection PyTypeChecker
-            aggregate_cls: Type[Aggregate] = import_module(diff.name)
-            return aggregate_cls.from_diff(diff)
+            aggregate_cls: Type[Aggregate] = import_module(aggregate_diff.name)
+            return aggregate_cls.from_diff(aggregate_diff, **kwargs)
 
-        if previous.version >= diff.version:
-            raise MinosPreviousVersionSnapshotException(previous, diff)
+        if previous.version >= aggregate_diff.version:
+            raise MinosPreviousVersionSnapshotException(previous, aggregate_diff)
 
-        previous.apply_diff(diff)
+        previous.apply_diff(aggregate_diff)
         return previous
 
-    async def _select_one_aggregate(self, aggregate_uuid: UUID, aggregate_name: str) -> Aggregate:
-        snapshot_entry = await self._select_one(aggregate_uuid, aggregate_name)
-        return snapshot_entry.aggregate
+    async def _select_one_aggregate(self, aggregate_uuid: UUID, aggregate_name: str, **kwargs) -> Aggregate:
+        snapshot_entry = await self._select_one(aggregate_uuid, aggregate_name, **kwargs)
+        return snapshot_entry.build_aggregate(**kwargs)
 
-    async def _select_one(self, aggregate_uuid: UUID, aggregate_name: str) -> SnapshotEntry:
-        raw = await self.submit_query_and_fetchone(_SELECT_ONE_SNAPSHOT_ENTRY_QUERY, (aggregate_uuid, aggregate_name))
+    async def _select_one(self, aggregate_uuid: UUID, aggregate_name: str, **kwargs) -> SnapshotEntry:
+        raw = await self.submit_query_and_fetchone(
+            _SELECT_ONE_SNAPSHOT_ENTRY_QUERY, (aggregate_uuid, aggregate_name), **kwargs
+        )
         return SnapshotEntry(aggregate_uuid, aggregate_name, *raw)
 
-    async def _submit_instance(self, aggregate: Aggregate) -> SnapshotEntry:
+    async def _submit_instance(self, aggregate: Aggregate, **kwargs) -> SnapshotEntry:
         snapshot_entry = SnapshotEntry.from_aggregate(aggregate)
-        snapshot_entry = await self._submit_update_or_create(snapshot_entry)
+        snapshot_entry = await self._submit_update_or_create(snapshot_entry, **kwargs)
         return snapshot_entry
 
-    async def _submit_update_or_create(self, entry: SnapshotEntry) -> SnapshotEntry:
+    async def _submit_update_or_create(self, entry: SnapshotEntry, **kwargs) -> SnapshotEntry:
         params = {
             "aggregate_uuid": entry.aggregate_uuid,
             "aggregate_name": entry.aggregate_name,
             "version": entry.version,
             "data": entry.data,
         }
-        response = await self.submit_query_and_fetchone(_INSERT_ONE_SNAPSHOT_ENTRY_QUERY, params)
+        response = await self.submit_query_and_fetchone(_INSERT_ONE_SNAPSHOT_ENTRY_QUERY, params, **kwargs)
 
         entry.created_at, entry.updated_at = response
 
